;; Generated package description from denote-sequence.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-sequence" "0.2.0.0.20251216.160327" "Sequence notes or Folgezettel with Denote" '((emacs "28.1") (denote "4.0.0")) :commit "1de4854b6865fd54ebb2a36ef042cfa6b639acfe" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-sequence")
